@@ -5,14 +5,14 @@
 #' @title Package RWsearch
 #' @description
 #' Search by keywords in R packages, task views, CRAN, the web and display the results in
-#' console, txt, html or pdf pages. Within a single instruction, download the whole documentation 
-#' (html index, pdf manual, readme, vignettes, source code, etc), either in a flat format 
-#' or in subdirectories defined by the keywords. Several functions for task view maintenance. 
-#' Quick links to more than 60 web search engines. 
+#' console, txt, html or pdf pages. Download the whole documentation (html index, pdf manual, 
+#' readme, vignettes, source code, etc) with a single instruction, either in a flat format 
+#' or in subdirectories defined by the keywords. Visualize the package dependencies. 
+#' Several functions for task view maintenance and exploration of CRAN archive. 
+#' Quick links to more than 70 web search engines. 
 #' Lazy evaluation of non-standard content is available throughout the package and eases 
 #' the use of many functions. Packages RWsearch and pacman share the same syntax and 
-#' complement each other. Inswpired by packages ctv, foghorn, latexpdf, packagefinder, 
-#' pacman, sos, websearchr. 
+#' complement each other. Inspired by packages ctv, foghorn, latexpdf, pacman, sos. 
 #' 
 #' @examples
 #' ### NON-STANDARD CONTENT - NON-STANDARD EVALUATION
@@ -84,20 +84,38 @@
 #' ## List the task views
 #' tvdb_vec()
 #' tvdb_pkgs(gR, Genetics, Robust)
-#'
+#' 
+#' ## Search for some packages in the task views
+#' s_tvdb(actuar, FatTailsR, MASS, zoo, nopackage)
+#' 
 #' ## Search for the recent packages in crandb that contain the keyword 
 #' ## and verify if the packages are already refereed in the task view.
 #' ## from = "2017-01-01" and "2018-01-01" are selected for this small example.
 #' s_crandb_tvdb("distribution", tv = "Distributions", from = "2017-01-01")
 #' s_crandb_tvdb("distribution", tv = "Distributions", from = "2018-01-01")
+#' \donttest{
+#' ### EXPLORE CRAN ARCHIVE AND DOWNLOAD OLD tar.gz FILES
+#' ## In real life, download archivedb and crandb from CRAN
+#' ## with the functions archivedb_down() and crandb_down().  
+#' ## In this example, we load two small files (50 and 43 packages).
+#' crandb_load(system.file("data", "zcrandb.rda", package = "RWsearch"))
+#' archivedb_load(system.file("zarchive", "zCRAN-archive.html", package = "RWsearch")) 
+#' archivedb_npkgs()
+#' lapply(archivedb_list(), tail)
 #' 
-#' @import  parallel
-#' @import  utils
-#' @importFrom  brew        brew
-#' @importFrom  latexpdf    as.tabular  command
-#' @importFrom  sig         sig   list_sigs
-#' @importFrom  sos         findFn
-#' @importFrom  tools       texi2pdf
+#' ## Download the latest tar.gz version from CRAN archive 
+#' ## (this works for both both existing and removed packages).
+#' p_downarch(fitur, zmatrix, dir = file.path(tempdir(), "pdownarch"))
+#' }
+#' 
+#' @import      tools
+#' @import      utils
+#' @importFrom  brew      brew
+#' @importFrom  latexpdf  as.tabular  command
+#' @importFrom  networkD3 forceNetwork  sankeyNetwork
+#' @importFrom  sig       list_sigs   sig
+#' @importFrom  sos       findFn
+#' @importFrom  XML       readHTMLTable
 #' @aliases RWsearch
 #' @name    RWsearch-package
 #' @docType package
@@ -107,6 +125,7 @@ NULL
 
 
 
+
 #' @title  File zcrandb.rda: A Subset of crandb Dataset
 #' @description
 #' File \emph{zcrandb.rda} loads in .Globalenv as \code{crandb}, a data.frame of dim 50 x 65. 
@@ -141,3 +160,15 @@ NULL
 
 
 
+## CLOSE CONNECTIONS
+close_libcurl <- function() {
+    sc  <- showConnections(all = TRUE)
+    nc  <- rownames(sc)  
+    num <- which(sc[,"class"] == "url-libcurl" & sc[,"isopen"] == "closed")
+invisible(tryCatch(lapply(nc[num], function(n) close(getConnection(n))), 
+          condition = function(cond) {}))
+}
+
+
+
+
