@@ -66,6 +66,14 @@ h_crantv <- function(repos = getOption("repos")[1]) {
 utils::browseURL(z)
 }
 
+#' @export
+#' @rdname h_R
+h_cranstatus <- function() {
+    z <- "https://cran.r-project.org/mirmon_report.html"
+    message("Open CRAN mirror status in browser")
+utils::browseURL(z)
+}
+
 #' @export
 #' @rdname h_R
 h_cranberries <- function() {
